What time is it?
What's the date today?
What's the date tomorrow?
what's the date in 6 days?
What month is it?
What year is it?

What's the weather like?
What's the weather like in Toronto?
What time will the sunrise?
What time did the sunrise?
What time will the sun set?
What time did the sun set?
What's the air pressure today?

Hello
Hi
Hey
How are you?
How's it going?
What are you doing?
What are you up to?
Say that again?
Repeat that
